@@ -1,7 +1,6 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from .helpers import normalize_space
+from .helpers import normalize_space, titlecase
 from .exceptions import NotValidMetadataError
 
 # For now you cannot add custom fields!
@@ -42,6 +41,7 @@ class Metadata(object):
         if 'Authors' not in filtre:
             self._content['Authors'] = [broom(i) for i in
                                         self._content['Authors']]
+        self._content['Title'] = titlecase(self._content['Title'])
 
     @property
     def value(self):
@@ -82,7 +82,8 @@ class Metadata(object):
         """
         # by default do nothing
         self._content.update((k, v) for k, v in record.items()
-                             if k in overwrite and not overrule(v))
+                             if k in overwrite and not overrule(v) or
+                             self._content[k] == '')
         if not self._validate():
             self._set_empty()
             raise NotValidMetadataError()
